// pdf2tif.cpp : Defines the entry point for the application.
//

#include <windows.h>
#include <windowsx.h>
#include <commctrl.h>
#include <commdlg.h>

#include <time.h>
#include <stdio.h>
#include <sys/types.h>
#include <sys/timeb.h>
#include <stdlib.h>

#include <string>
#include <vector>
using namespace std;

extern "C" __declspec(dllexport) 
int __stdcall PDFToImageConverter(const char *szPDFFileName, const char *szOutputName,
			       const char *szUserPassword, const char *szOwnPassword,
			       int xresolution, int yresolution, int bitcount, 
			       int compression, int quality, BOOL grayscale, 
			       BOOL multipage,  int firstPage,int lastPage);

extern "C" __declspec(dllexport)
int __stdcall TIFFImageGetPageCount(char *inputTIFFFile);
extern "C" __declspec(dllexport)
int __stdcall TIFFImageGetColors(char *inputTIFFFile, int pageno);
extern "C" __declspec(dllexport)
int __stdcall TIFFImageGetCompression(char *inputTIFFFile, int pageno);

#define	    COMPRESSION_NONE		1	/* dump mode */
#define	    COMPRESSION_CCITTRLE	2	/* CCITT modified Huffman RLE */
#define	    COMPRESSION_CCITTFAX3	3	/* CCITT Group 3 fax encoding */
#define	    COMPRESSION_CCITTFAX4	4	/* CCITT Group 4 fax encoding */
#define	    COMPRESSION_LZW		5       /* Lempel-Ziv  & Welch */
#define	    COMPRESSION_JPEG		7	/* %JPEG DCT compression */
#define	    COMPRESSION_PACKBITS	32773	/* Macintosh RLE */
///////////////////////////////////////////
//
//  Set options into a TIFF file
//
//  Parameters
//
//  char *inputTIFFFile:  input TIFF file
//  int pageno:  specify page index
//  int colors:  specify colors, it can be 1, 4, 8, 24
//  int compression: 
//#define	    COMPRESSION_NONE		1	/* dump mode */
//#define	    COMPRESSION_CCITTRLE	2	/* CCITT modified Huffman RLE */
//#define	    COMPRESSION_CCITTFAX3	3	/* CCITT Group 3 fax encoding */
//#define     COMPRESSION_CCITT_T4        3       /* CCITT T.4 (TIFF 6 name) */
//#define	    COMPRESSION_CCITTFAX4	4	/* CCITT Group 4 fax encoding */
//#define     COMPRESSION_CCITT_T6        4       /* CCITT T.6 (TIFF 6 name) */
//#define	    COMPRESSION_LZW		5       /* Lempel-Ziv  & Welch */
//#define	    COMPRESSION_OJPEG		6	/* !6.0 JPEG */
//#define	    COMPRESSION_JPEG		7	/* %JPEG DCT compression */
//
//
///////////////////////////////////////////
extern "C" __declspec(dllexport)
int __stdcall TIFFImageSetOptions(char *inputTIFFFile, int pageno, int colors, int compression);

char INIFILENAME[MAX_PATH];
HINSTANCE	hInst		= NULL;		// current instance
vector<string>	m_szPDFFileAry;
VOID	GetFileName(HWND hWnd)
{
	char path_buffer[_MAX_PATH];
	char drive[_MAX_DRIVE];
	char dir[_MAX_DIR];
	char fname[_MAX_PATH];
	char ext[_MAX_EXT];

	m_szPDFFileAry.erase(m_szPDFFileAry.begin(),m_szPDFFileAry.end());

	OPENFILENAME ofn;
	//file type filters
	CHAR szFilterSpec[] = "PDF Files(*.pdf)\0*.pdf\0All Files(*.*)\0*.*\0\0";
	CHAR szFileTitle[MAX_PATH];
	
	strcpy(szFileTitle, "");

	CHAR strInitialDir[MAX_PATH];
	GetPrivateProfileString("Paramter","InitialDir","",strInitialDir,MAX_PATH,INIFILENAME);

	
	char *m_pChBuf = NULL;
	if ( ( m_pChBuf	= ( char * ) malloc( 1024*100 )) == NULL )
		return;
	memset(m_pChBuf,0,1024*100);
	//fill in non-variant fields of OPENFILENAME struct.
	ofn.lStructSize		= sizeof(OPENFILENAME);
	ofn.hwndOwner		= hWnd;
	ofn.hInstance		= hInst;
	ofn.lpstrFilter		= szFilterSpec;
	ofn.lpstrCustomFilter	= NULL;
	ofn.nMaxCustFilter	= 0;
	ofn.nFilterIndex	= 0;
	ofn.lpstrFile		= m_pChBuf;
	ofn.nMaxFile		= 20000;
	ofn.lpstrInitialDir	= strInitialDir;
	ofn.lpstrFileTitle	= szFileTitle;
	ofn.nMaxFileTitle	= MAX_PATH;
	ofn.lpstrTitle		= "PDF to TIFF software";
	ofn.lpstrDefExt		= "PDF";
	ofn.Flags		= OFN_FILEMUSTEXIST | OFN_HIDEREADONLY|OFN_ALLOWMULTISELECT|OFN_EXPLORER;

	//Use standard open dialog
	if (!GetOpenFileName ((LPOPENFILENAME)&ofn))
	{
	}
	else
	{
		char* pChBuf = m_pChBuf;
		pChBuf += strlen( pChBuf ) + 1;
		if ( *pChBuf == 0 )		//only one file
		{
			_splitpath(m_pChBuf, drive, dir, fname, ext );
			_makepath(path_buffer,drive, dir,"","");
			WritePrivateProfileString("Paramter","InitialDir",path_buffer,INIFILENAME);
			m_szPDFFileAry.push_back(m_pChBuf);
		}
		else
		{//multiple files
			while(*pChBuf)
			{
				strcpy(path_buffer,m_pChBuf);
				if(path_buffer[strlen(path_buffer)-1] != '\\\\')
					strcat(path_buffer,"\\\\");
				strcat(path_buffer,pChBuf);
				m_szPDFFileAry.push_back(path_buffer);
				pChBuf += strlen( pChBuf ) + 1;
			}
			WritePrivateProfileString("Paramter","InitialDir",m_pChBuf,INIFILENAME);
		}
	}
	free(m_pChBuf);
	return;
}
void StructureIniFileName()
{
	CHAR	szExeDir[MAX_PATH];
	GetModuleFileName(hInst,szExeDir,MAX_PATH);
	CHAR drive[_MAX_DRIVE],dir[_MAX_DIR],fname[_MAX_FNAME],ext[_MAX_EXT];
	_splitpath(szExeDir, drive, dir, fname, ext );
	_makepath(INIFILENAME, drive, dir,"config",".ini");
}
int APIENTRY WinMain(HINSTANCE hInstance,
                     HINSTANCE hPrevInstance,
                     LPSTR     lpCmdLine,
                     int       nCmdShow)
{
	hInst = hInstance;
	StructureIniFileName();

	if(__argc != 3)
	{
		char path_buffer[_MAX_PATH];
		char drive[_MAX_DRIVE];
		char dir[_MAX_DIR];
		char fname[_MAX_PATH];
		char ext[_MAX_EXT];

		GetFileName(GetDesktopWindow());
		int nsize = m_szPDFFileAry.size();
		if(nsize == 0)
			return 0;
		int result = 0;
		for(int i = 0; i < nsize; i++)
		{
			const char *szPDFName = m_szPDFFileAry[i].c_str();
			_splitpath(szPDFName, drive, dir, fname, ext );
			_makepath(path_buffer,drive, dir,fname,".tif");
			
			result = PDFToImageConverter(szPDFName,path_buffer,NULL,NULL,200,200,24,
				COMPRESSION_PACKBITS,70,FALSE,TRUE,-1,-1);
		}
		//MessageBox(NULL,"Convert OK","PDF2TIFF",MB_OK);
		return 0;
	}
	char *szPDFFileName = __argv[1];
	char *szOutputName  = __argv[2];
	int result = result = PDFToImageConverter(szPDFFileName,szOutputName,NULL,NULL,200,200,8,
		COMPRESSION_PACKBITS,70,TRUE,TRUE,-1,-1);
	//result = TIFFImageSetOptions(szOutputName,-1,1,COMPRESSION_NONE);
	char buffer[200];
	sprintf(buffer,"Return value is %d",result);
	MessageBox(NULL,buffer,"PDF To Image SDK",MB_OK);
	return result;
}